@@ -27,7 +27,7 @@
 #include <cmath>
 
 #include <klocale.h>
-#include <kdebug.h>
+#include <QDebug>
 
 using std::fabs;
 using std::cos;
@@ -794,7 +794,6 @@ bool operator==( const Transformation& lhs, const Transformation& rhs )
 const Transformation Transformation::similitude(
   const Coordinate& center, double theta, double factor )
 {
-  //kDebug() << "theta: " << theta << " factor: " << factor;
   Transformation ret;
   ret.mIsHomothety = true;
   double costheta = cos( theta );
